==> question2answer-1.3-language-pt-BR.zip: pt/qa-lang-main.php <==
<?php
	
/*
	Question2Answer 1.3 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-main.php
	Version: 1.3
	Date: 2010-11-23 06:34:00 GMT
	Description: Language phrases commonly used throughout Q2A
	Language: Português - Brasil
  Author: André Ortega - www.brainwork.com.br/qa

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 resposta',
		'1_day' => '1 dia',
		'1_disliked' => '1 contra',
		'1_hour' => '1 hora',
		'1_liked' => '1 a favor',
		'1_minute' => '1 minuto',
		'1_month' => '1 mês',
		'1_point' => '1 ponto',
		'1_question' => '1 pergunta',
		'1_second' => '1 segundo',
		'1_vote' => '1 voto',
		'1_week' => '1 semana',
		'1_year' => '1 ano',
		'all_categories' => 'Todas as categorias',
		'anonymous' => 'anônimo',
		'answer_edited' => 'resposta editada',
		'answered' => 'respondida',
		'asked' => 'perguntado',
		'by_x' => 'por ^',
		'cancel_button' => 'Cancelar',
		'comment_edited' => 'comentário editado',
		'commented' => 'comentado',
		'edited' => 'editado',
'field_required' => 'Por favor, não deixe o campo em branco',
		'general_error' => 'Ocorreu um erro no servidor - Por favor tente novamente.',
		'highest_users' => 'Usuários com mais pontos',
		'in_category_x' => 'em ^',
		'ip_address_x' => 'Endereço IP ^',
		'logged_in_x' => 'Olá ^',
		'max_length_x' => 'Tamanho máximo de ^ caracteres',
		'me' => 'eu',
		'meta_order' => '^what^when^where^who', // sets order of elements like: <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Por favor forneça mais informação (pelo menos ^ caracteres)',
		'nav_account' => 'Minha conta',
		'nav_activity' => 'Todas atividades',
		'nav_admin' => 'Admin',
		'nav_ask' => 'Faça uma pergunta',
		'nav_categories' => 'Categorias',
		'nav_feedback' => 'Envie sua opinião',
		'nav_home' => 'Home',
		'nav_login' => 'Login',
		'nav_logout' => 'Logout',
		'nav_qa' => 'Q&A',
		'nav_qs' => 'Perguntas',
		'nav_register' => 'Registro',
		'nav_tags' => 'Tags',
		'nav_unanswered' => 'Sem respostas',
		'nav_users' => 'Usuários',
		'no_active_users' => 'Não foram encontrados usuários ativos',
		'no_answers_found' => 'Não foram encontradas respostas',
		'no_answers_in_x' => 'Nenhuma resposta em ^',
		'no_categories_found' => 'Nenhuma categoria encontrada',
		'no_category' => 'Nenhuma categoria',
		'no_comments_found' => 'Nenhum comentário encontrado',
		'no_comments_in_x' => 'Nenhum comentário em ^',
		'no_questions_found_in_x' => 'Nenhuma questão encontrada em ^',
		'no_questions_found' => 'Não foram encontradas perguntas',
		'no_related_qs_title' => 'Nenhuma questão relacionada',
		'no_results_for_x' => 'Nenhum resultado para ^',
		'no_tags_found' => 'Nenhuma tag encontrada',
		'no_una_questions_found' => 'Não foi encontrada nenhuma pergunta sem resposta',
		'no_una_questions_in_x' => 'Não foi encontrada nenhuma pergunta sem resposta em ^',
		'page_label' => 'Página:',
		'page_next' => 'próximo',
		'page_not_found' => 'Página não encontrada',
		'page_prev' => 'anterior',
		'popular_tags' => 'Tags mais populares',
		'questions_tagged_x' => 'Perguntas recentes tagged ^',
		'recent_activity_in_x' => 'Perguntas, respostas e comentários recentes em ^',
		'recent_activity_title' => 'Perguntas, respostas e comentários recentes',
		'recent_as_in_x' => 'Perguntas respondidas recentemente em ^',
		'recent_as_title' => 'Perguntas respondidas recentemente',
		'recent_cs_in_x' => 'Comentários adicionados recentemente em ^',
		'recent_cs_title' => 'Comentários adicionados recentemente',
		'recent_qs_as_in_x' => 'Perguntas e respostas recentes em ^',
		'recent_qs_as_title' => 'Perguntas e respostas recentes',
		'recent_qs_in_x' => 'Perguntas recentes em ^',
		'recent_qs_title' => 'Perguntas recentes',
		'related_qs_title' => 'Perguntas relacionadas',
		'results_for_x' => 'Resultado da busca ^',
		'save_button' => 'Salvar alterações',
		'search_button' => 'Pesquisar',
		'search_title' => 'Pesquisar Pergunta',
		'send_button' => 'Enviar',
		'suggest_ask' => 'Participe ^1fazendo uma pergunta^2.',
		'suggest_category_qs' => 'Clique para ver todas as ^1perguntas nesta categoria^2.',
		'suggest_qs_tags' => 'Para ver mais clique na ^1lista completa de questões^2 ou ^3nas tags populares^4.',
		'suggest_qs' => 'Clique para ver a ^1lista completa de perguntas^2.',
		'unanswered_qs_in_x' => 'Perguntas recentes sem respostas em ^',
		'unanswered_qs_title' => 'Perguntas recentes sem respostas',
		'vote_disabled_hidden_a' => 'Você não pode votar em respostas ocultas',
		'vote_disabled_hidden_q' => 'Você não pode votar em perguntas ocultas',
		'vote_disabled_my_a' => 'Você não pode votar em suas próprias respostas',
		'vote_disabled_my_q' => 'Você não pode votar em suas próprias perguntas',
		'vote_disabled_q_page_only' => 'Por favor, para votar veja a pergunta',
		'vote_down_popup' => 'Clique para votar contra',
		'vote_limit' => 'Muitos votos recebidos - Por favor tente mais tarde',
		'vote_must_confirm' => 'Por favor ^5confirme seu endereço de email^6 para votar.',
		'vote_must_login' => 'Por favor ^1faça o login^2 ou ^3registre-se^4 para votar.',
		'vote_not_allowed' => 'Não é permitido votar nisto',
		'vote_up_popup' => 'Clique para votar',
		'voted_down_popup' => 'Você votou contra - clique para remover o voto',
		'voted_up_popup' => 'Você votou a favor - clique para remover o voto',
		'x_ago' => '^ atrás',
		'x_answers' => '^ respostas',
		'x_days' => '^ dias',
		'x_disliked' => '^ contra',
		'x_hours' => '^ horas',
		'x_liked' => '^ a favor',
		'x_minutes' => '^ minutos',
		'x_months' => '^ meses',
		'x_points' => '^ pontos',
		'x_questions' => '^ perguntas',
		'x_seconds' => '^ segundos',
		'x_votes' => '^ votos',
		'x_weeks' => '^ semanas',
		'x_years' => '^ anos',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.4-language-pt-BR.zip: pt/qa-lang-main.php <==
<?php
	
/*
	Question2Answer 1.4.1 (c) 2011, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-main.php
	Version: 1.4.1
	Date: 2011-07-10 06:58:57 GMT
	Description: Language phrases commonly used throughout Q2A


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 resposta',
		'1_comment' => '1 comentário',
		'1_day' => '1 dia',
		'1_disliked' => '1 contra',
		'1_flag' => '1 flag',
		'1_hour' => '1 hora',
		'1_liked' => '1 gostou',
		'1_minute' => '1 minuto',
		'1_month' => '1 mês',
		'1_point' => '1 ponto',
		'1_question' => '1 pergunta',
		'1_second' => '1 segundo',
		'1_user' => '1 usuário',
		'1_view' => '1 visualização',
		'1_vote' => '1 voto',
		'1_week' => '1 semana',
		'1_year' => '1 ano',
		'all_categories' => 'Todas as categorias',
		'anonymous' => 'anônimo',
		'answer_edited' => 'resposta editada',
		'answered_qs_title' => 'Todas as perguntas mais respondidas',
		'answered' => 'respondida',
		'asked' => 'perguntado',
		'by_x' => 'por ^',
		'cancel_button' => 'Cancelar',
		'comment_edited' => 'comentário editado',
		'commented' => 'comentado',
		'edited' => 'editado',
		'field_required' => 'Por favor, não deixe o campo em branco',
		'general_error' => 'Ocorreu um erro no servidor - Por favor tente novamente.',
		'highest_users' => 'Usuários com mais pontos',
		'hot_qs_title' => 'Perguntas mais populares',
		'image_not_read' => 'A imagem não pode ser lida. Por favor upload uma de: ^',
		'image_too_big_x_pc' => 'Esta imagem é muito grande. Por favor redimensione para  ^% e tente novamente.',
			'in_category_x' => 'em ^',
		'ip_address_x' => 'Endereço IP ^',
		'logged_in_x' => 'Olá ^',
		'max_length_x' => 'Tamanho máximo de ^ caracteres',
		'me' => 'eu',
		'meta_order' => '^what^when^where^who', // sets order of elements like: <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Por favor forneça mais informação (pelo menos ^ caracteres)',
		'nav_account' => 'Minha conta',
		'nav_activity' => 'Todas atividades',
		'nav_admin' => 'Admin',
		'nav_ask' => 'Faça uma pergunta',
		'nav_categories' => 'Categorias',
		'nav_feedback' => 'Envie sua opinião',
		'nav_home' => 'Home',
		'nav_hot' => 'Populares',
		'nav_login' => 'Login',
		'nav_logout' => 'Sair',
		'nav_most_answers' => 'Mais respondidas',
		'nav_most_recent' => 'Recentes',
		'nav_most_views' => 'Mais visualizadas',
		'nav_most_votes' => 'Mais votadas',
		'nav_qa' => 'Q&A',
		'nav_qs' => 'Perguntas',
		'nav_register' => 'Registro',
		'nav_tags' => 'Tags',
		'nav_unanswered' => 'Sem respostas',
		'nav_users' => 'Usuários',
		'no_active_users' => 'Não foram encontrados usuários ativos',
		'no_answers_found' => 'Não foram encontradas respostas',
		'no_answers_in_x' => 'Nenhuma resposta em ^',
		'no_categories_found' => 'Não foi encontrada categorias',
		'no_category' => 'Nenhuma categoria',
		'no_comments_found' => 'Não foram encontrados comentários',
		'no_comments_in_x' => 'Nenhum comentário em ^',
		'no_questions_found' => 'Não foram encontradas perguntas',
		'no_questions_in_x' => 'Perguntas não encontradas em  ^',
		'no_related_qs_title' => 'Não foram encontradas perguntas relacionadas',
		'no_results_for_x' => 'Nenhum resultado para ^',
		'no_tags_found' => 'Nenhuma tag encontrada',
		'no_una_questions_found' => 'Não foi encontrada nenhuma pergunta sem resposta',
		'page_label' => 'Página:',
		'page_next' => 'próximo',
		'page_not_found' => 'Página não encontrada',
		'page_prev' => 'anterior',
		'popular_tags' => 'Tags mais populares',
		'questions_tagged_x' => 'Perguntas recentes com a tag ^',
		'recent_activity_in_x' => 'Atividade recente em ^',
		'recent_activity_title' => 'Atividades recentes',
		'recent_as_in_x' => 'Perguntas respondidas recentemente em ^',
		'recent_as_title' => 'Perguntas respondidas recentemente',
		'recent_cs_in_x' => 'Comentários adicionados recentemente em ^',
		'recent_cs_title' => 'Comentários adicionados recentemente',
		'recent_qs_as_in_x' => 'Perguntas e respostas recentes em ^',
		'recent_qs_as_title' => 'Perguntas e respostas recentes',
		'recent_qs_in_x' => 'Perguntas recentes em ^',
		'recent_qs_title' => 'Perguntas recentes',
		'related_qs_title' => 'Perguntas relacionadas',
		'results_for_x' => 'Resultado da busca ^',
		'save_button' => 'Salvar alterações',
		'search_button' => 'Pesquisar',
		'search_title' => 'Pesquisar Pergunta',
		'send_button' => 'Enviar',
		'suggest_ask' => 'Participe ^1fazendo uma pergunta^2.',
		'suggest_category_qs' => 'Clique para ver todas as ^1perguntas nesta categoria^2.',
		'suggest_qs_tags' => 'Para ver mais clique na ^1lista completa de perguntas^2 ou ^3nas tags populares^4.',
		'suggest_qs' => 'Clique para ver a ^1lista completa de perguntas^2.',
		'unanswered_qs_in_x' => 'Perguntas recentes sem respostas em ^',
		'unanswered_qs_title' => 'Perguntas recentes sem respostas',
		'upload_limit' => 'Muitos uploads - por favor tente novamente em uma hora',
		'view_q_must_confirm' => 'Por favor ^5confirme o seu endereço de email^6 para ver as perguntas.',
		'view_q_must_login' => 'Por favor ^1logue^2 ou ^3registre-se^4 para ver a página de respostas.',
		'viewed_qs_title' => 'Perguntas mais vistas',
		'vote_disabled_hidden_a' => 'Você não pode votar em respostas ocultas',
		'vote_disabled_hidden_q' => 'Você não pode votar em perguntas ocultas',
		'vote_disabled_level' => 'Voto está permitido somente para alguns usuários',
		'vote_disabled_my_a' => 'Você não pode votar em suas próprias respostas',
		'vote_disabled_my_q' => 'Você não pode votar em suas próprias perguntas',
		'vote_disabled_q_page_only' => 'Por favor leia uma pergunta para votar',
		'vote_down_popup' => 'Clique para votar contra',
		'vote_limit' => 'Muitos votos recebidos - Por favor tente mais tarde',
		'vote_must_confirm' => 'Por favor ^5confirme seu endereço de email^6 para votar.',
		'vote_must_login' => 'Por favor ^1faça o login^2 ou ^3registre-se^4 para votar.',
		'vote_not_allowed' => 'Não é permitido votar nisto',
		'vote_up_popup' => 'Clique para votar a favor',
		'voted_down_popup' => 'Você votou contra - clique para remover o voto',
		'voted_qs_title' => 'Perguntas mais votadas',
		'voted_up_popup' => 'Você votou a favor - clique para remover o voto',
		'x_ago' => '^ atrás',
		'x_answers' => '^ respostas',
		'x_comments' => '^ comentários',
		'x_days' => '^ dias',
		'x_disliked' => '^ contra',
		'x_flags' => '^ flags',
		'x_hours' => '^ horas',
		'x_liked' => '^ favor',
		'x_minutes' => '^ minutos',
		'x_months' => '^ meses',
		'x_points' => '^ pontos',
		'x_questions' => '^ perguntas',
		'x_seconds' => '^ segundos',
		'x_users' => '^ usuarios',
		'x_views' => '^ visualizações',
		'x_votes' => '^ votos',
		'x_weeks' => '^ semana',
		'x_years' => '^ anos',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
